@@ -11,6 +11,7 @@ try:
 except:
 	import gconf
 import osso
+import re
 
 class fAPN_helper:
 	def __init__(self):
@@ -24,7 +25,11 @@ class fAPN_helper:
 		
 	def add_new_apn(self, apname, simimsi):
 		print "adding:", apname, simimsi
-		gconfdir = apname.replace(" ", "@32@")
+		gconfdir = re.search(r"[a-zA-Z0-9\ .]+", apname)
+		gconfdir = gconfdir.group()
+		gconfdir = gconfdir.replace(" ", "@32@")
+		gconfdir = gconfdir.replace(".", "@46@")
+		print gconfdir
 		self.client.add_dir(self._iapdir + "/" + gconfdir, gconf.CLIENT_PRELOAD_NONE)
 		self.client.set_string(self._iapdir + "/" + gconfdir + "/type", "GPRS")
 		self.client.set_string(self._iapdir + "/" + gconfdir + "/name", apname)
@@ -119,5 +124,5 @@ if __name__ == '__main__':
 	#config.remove_apn("NEWAPNNAME")
 	#print config.get_simimsi_from_apn()
 	#print config.get_apn_list_useradded()
-	#config.add_new_apn("NEWAPNNAME", config.get_simimsi_from_apn())
+	#config.add_new_apn("ä test 123.de ä ", config.get_simimsi_from_apn())
 	#print config.get_simimsi_from_apn()
\ No newline at end of file
